#
# spec file for package wine-nine-standalone
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wine-nine-standalone
Version:        0.9
Release:        1.2
Summary:        Wine Gallium Nine Standalone version
License:        LGPL-2.1-or-later
Group:          System/Emulators/PC
URL:            https://github.com/iXit/wine-nine-standalone
Source0:        https://github.com/iXit/wine-nine-standalone/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# git snapshot to make it build
#Source0:        wine-nine-standalone.tar.bz2
Source2:        baselibs.conf
BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGL-devel
BuildRequires:  Mesa-libd3d-devel
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libX11-devel
BuildRequires:  meson
BuildRequires:  wine
BuildRequires:  wine-devel
Requires:       Mesa-libd3d
Obsoletes:      wine-nine < 4.2
ExclusiveArch:  %{ix86} x86_64

%description
Gallium Nine allows to run any Direct3D 9 application with nearly no CPU
overhead, which provides a smoother gaming experience and increased FPS.

Gallium Nine Standalone, as the name implies, is a standalone version of the WINE parts of Gallium Nine.

This decouples Gallium Nine from the WINE tree, so that it can be used
with any WINE version. There is no need for any WINE patches. A stable,
development, or staging WINE release is sufficient.

Gallium Nine Standalone consists of two parts:

* d3d9-nine.dll: Gallium Nine Direct3D 9 library
* ninewinecfg.exe: GUI to enable/disable Gallium Nine with some additional info about the current state

%prep
%setup -q

%build

sed "s/@PKG_CONFIG@/pkg-config/" \
        < tools/cross-wine32.in \
        > tools/cross-wine32

sed "s/@PKG_CONFIG@/pkg-config/" \
        < tools/cross-wine64.in \
        > tools/cross-wine64

CROSS=tools/cross-wine64
[ %{_lib} = "lib" ] && CROSS=tools/cross-wine32

%meson --cross-file $CROSS --bindir=%{_libdir}/wine --libdir=%{_libdir}/wine || cat /home/abuild/rpmbuild/BUILD/wine-nine-standalone-0.4/*/meson-logs/meson-log.txt
%meson_build

%install
%meson_install

mkdir %{buildroot}%{_libdir}/wine/fakedlls
mv %{buildroot}%{_libdir}/wine/d3d9-nine.dll.fake %{buildroot}%{_libdir}/wine/fakedlls/d3d9-nine.dll
mv %{buildroot}%{_libdir}/wine/ninewinecfg.exe.fake %{buildroot}%{_libdir}/wine/fakedlls/ninewinecfg.exe

%files
%license LICENSE
%doc README.rst
%dir %{_libdir}/wine
%{_libdir}/wine/*.so
%dir %{_libdir}/wine/fakedlls
%{_libdir}/wine/fakedlls/*

%changelog
* Sat Mar 16 2024 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 0.9.
  * The original d3d9.dll is restored when disabling Gallium Nine.
  * New Portuguese translation.
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- avoid bashism
* Sat Apr  9 2022 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Mesa-libd3d's d3dadapter9.so is loaded with dlopen and thus not
  automatically recognized as runtime dependency, add it manually.
* Thu Apr 15 2021 Marcus Meissner <meissner@suse.com>
- updated to 0.8
  no upstream changelog
* Tue Mar 30 2021 Marcus Meissner <meissner@suse.com>
- fix build by taking current git temporary
* Thu Sep 10 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Build only on x86
* Wed Aug 19 2020 Marcus Meissner <meissner@suse.com>
- Version 0.7
  - Fix restoring the initial video mode
* Sat Aug 15 2020 Marcus Meissner <meissner@suse.com>
- Version 0.6
  - Add Japanese translation
  - Restore status messages when launching processes via explorer
  - GCC 10 build fix
  - Fix for WINE >= 5.14
* Tue Mar 31 2020 Hans-Peter Jansen <hpj@urpla.net>
- Version 0.5
  + ninewinecfg has a new '-p' switch to probe if the current setup
    is capable of using nine
  + Flatpak Steam support
  + ninewinecfg has been translated to czech
  + Fix mouse handling for hardware cursors
  + Add our own debug facility since binaries compiled against WINE
    >= v4.6 are not backwards compatible anymore
  + Always show the window on fullscreen resolution changes
  + Fix d3d/gui resolution mismatch on Vampire: The Masquerade -
    Bloodlines
  + Fix the dri2 backend if dri3 is unavailable
* Mon Aug 26 2019 Ismail Dönmez <idonmez@suse.com>
- Cleanup spec file
* Sat Aug 24 2019 Marcus Meissner <meissner@suse.com>
- gallium nine standalone version, imported 0.4
